#!/bin/bash

#   backup_diss.sh - this script creates tar.gz archives and places them in
#   a backup folder ordered by date where the latest is linked to a folder called "current"
#
#   DISS - Debian Install Server Scripts
#   A set of scripts to automate installation of Servers on Debian
#   (c) 2009 Emmanuel Revah - manu-at-manurevah.com
#
#   This file is part of DISS.
#
#   DISS is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   DISS is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with DISS.  If not, see <http://www.gnu.org/licenses/>.

source /etc/diss/diss.conf

logger "DISS backup script: started"
DATE=$(date +%a_%d_%b_%Y_%Hh%Mm%S)
MONTH=$(date +%B_%Y)


###########  configuration options ##############

# see /etc/diss.conf for other configuration options

# destination of this backup
BACKUP="${BACKUPROOT}/${MONTH}/backup_${DATE}/"

BACKUPDIRS=`ls -d ${BACKUPDIRS}`
MYSQL_USER_PASS="--user=root --password=${ROOTSQL}"

############ end of configuration ################

# cleanup up the "current" folder and link the new one
rm -f ${BACKUPROOT}/current
test -d ${BACKUP} || mkdir -p ${BACKUP}/mysql
ln -s ${BACKUP} ${BACKUPROOT}/current

# make some archive files
for DIRS in ${BACKUPDIRS}; do
	DIRNAME=`echo ${DIRS}|sed 's/\//_/g'`
	tar zcfp ${BACKUP}/${DATE}${DIRNAME}.tar.gz ${DIRS};
done

# mysql: please test this line to make sure it correctly lists the names of the databases
MYBASES="`ls -1 /var/lib/mysql |grep -v ib_* |grep -v debian-5.0.flag | grep -v mysql_upgrade_info`"
for DBS in ${MYBASES};do
        mysqldump --databases ${DBS} ${MYSQL_USER_PASS} > ${BACKUP}/mysql/${DATE}_${DBS}.sql
done
logger "DISS backup script: local backup done :]"

# crypt backup before sending elsewhere
tar -zcvf - ${BACKUP} |openssl des3 -salt -k ${BACKUPKEY} | dd of=${BACKUPROOT}/backup_${DATE}.des3

if [ -a "/etc/diss/ftp_pre_backup_commands" ]; then
	ncftp -u ${BACKUPFTPUSER} -p ${BACKUPFTPPASS} ${BACKUPFTPHOST} < /etc/diss/ftp_pre_backup_commands
fi
ncftpput -u ${BACKUPFTPUSER} -p ${BACKUPFTPPASS} ${BACKUPFTPHOST} ${BACKUPFTPDIR} ${BACKUPROOT}/backup_${DATE}.des3
logger "DISS backup script: upload current backup to ${NCFTPBOOKMARK}"

# create a little history file
cat ${BACKUPROOT}/md5sums | tail -n 4 > /tmp/bkp_md5
cat /tmp/bkp_md5 > ${BACKUPROOT}/md5sums
rm /tmp/bkp_md5
echo "`md5sum ${BACKUPROOT}/backup_${DATE}.des3`" >> ${BACKUPROOT}/md5sums
# we don't need to localy keep the .des3 backup file
rm ${BACKUPROOT}/backup_${DATE}.des3

find ${BACKUPROOT}  -type f -mtime +${BACKUPDAYS} -exec rm -rf {} \;
rmdir -p ${BACKUPROOT}/*/*/*

logger "DISS backup script: removed 5 day old backups"

exit
