#!/bin/bash

#   create_nimda.sh - create admin part for new clients
#
#   DISS - Debian Install Server Scripts
#   A set of scripts to automate installation of Servers on Debian
#   (c) 2009 Emmanuel Revah - manu-at-manurevah.com
#
#   This file is part of DISS.
#
#   DISS is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   DISS is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with DISS.  If not, see <http://www.gnu.org/licenses/>.


source /etc/diss/diss.conf

# adduser if needed
if [ "${CREATEUSER}" == "1" ]; then
        CLIENTNIXPASS=$(perl -e 'print crypt($ARGV[0], "password")' ${CLIENTPASS})
        useradd --shell /bin/false -p ${CLIENTNIXPASS} ${CLIENT} -d /home/www/html/${CLIENT}
        else
        echo " "
fi

mkdir -p /home/www/html/${CLIENT}/${NIMDA}.${DOMAIN}
cd /home/www/html/${CLIENT}/${NIMDA}.${DOMAIN}
ln -s /usr/share/phpmyadmin phashp
ln -s /home/www/outside-html/vmail_manager vmail_manager
cp /usr/local/${SOFTNAME}/nimda/index_nimda_client.php /home/www/html/${CLIENT}/${NIMDA}.${DOMAIN}/index.php
cp -r /usr/local/${SOFTNAME}/nimda/style/ /home/www/html/${CLIENT}/${NIMDA}.${DOMAIN}/
cp /usr/local/${SOFTNAME}/nimda/favicon.ico /home/www/html/${CLIENT}/${NIMDA}.${DOMAIN}/
chown -R root:www-data /home/www/html/${CLIENT}
chmod 750 /home/www/html/${CLIENT}/${NIMDA}.${DOMAIN}
mkdir /var/log/apache2/${CLIENT}/
echo "
	<li><a href=\"/awstats/awstats.pl?config=${NIMDA}.$DOMAIN\">${NIMDA}.${DOMAIN}</a></li>" > /home/www/html/${CLIENT}/${NIMDA}.${DOMAIN}/links.html

echo  "LogFile=\"/var/log/apache2/${CLIENT}/${NIMDA}.${DOMAIN}.log\"
SiteDomain=\"${NIMDA}.${DOMAIN}\"
AllowAccessFromWebToFollowingAuthenticatedUsers=\"${ADMINUSER} ${CLIENT}\"
DefaultFile=\"index.html\"
ShowFlagLinks=\"en de fr\"
Lang=\"en\"
Include \"include.conf\"" > /etc/awstats/awstats.${NIMDA}.${DOMAIN}.conf

echo "<VirtualHost *:80>
	ServerName ${NIMDA}.${DOMAIN}
	DocumentRoot /home/www/html/${CLIENT}/${NIMDA}.${DOMAIN}
	CustomLog /var/log/apache2/${CLIENT}/${NIMDA}.${DOMAIN}.log combined
	CustomLog /var/log/apache2/global.log combined

<Directory /home/www/html/${CLIENT}/${NIMDA}.${DOMAIN}/phashp>
	Options FollowSymLinks MultiViews
	AllowOverride None
	Order allow,deny
	allow from all
</Directory>

<Directory /home/www/html/${CLIENT}/${NIMDA}.${DOMAIN}>
	AllowOverride AuthConfig
	Options FollowSymLinks MultiViews
	Order allow,deny
	allow from all
</Directory>

Alias /awstatsicons \"/usr/share/awstats/icon/\"
ScriptAlias /awstats/awstats.pl \"/usr/lib/cgi-bin/awstats.pl/\"

</VirtualHost>" > /etc/apache2/sites-available/${CLIENT}_${NIMDA}.${DOMAIN}

a2ensite ${CLIENT}_${NIMDA}.$DOMAIN

htpasswd -mb /home/www/.htpasswd ${CLIENT} ${CLIENTPASS}
echo "AuthUserFile /home/www/.htpasswd
AuthName \"Please enter stuff\"
AuthType Basic

<Limit GET POST>
Require user ${ADMINUSER} ${CLIENT}
</Limit>" > /home/www/html/${CLIENT}/${NIMDA}.${DOMAIN}/.htaccess
chown root:www-data /home/www/html/${CLIENT}/${NIMDA}.${DOMAIN}/.htaccess
chmod 640 /home/www/html/${CLIENT}/${NIMDA}.${DOMAIN}/.htaccess

# create /var/www/php-fcgi-scripts/${CLIENT}/php-fcgi-starter
mkdir -p /var/www/php-fcgi-scripts/${CLIENT}
echo "#!/bin/sh
PHPRC=/etc/php5/cgi/
export PHPRC
export PHP_FCGI_MAX_REQUESTS=5000
export PHP_FCGI_CHILDREN=8
exec /usr/lib/cgi-bin/php" > /var/www/php-fcgi-scripts/${CLIENT}/php-fcgi-starter
chown -R ${CLIENT}:${CLIENT} /var/www/php-fcgi-scripts/${CLIENT}/
chmod 755 /var/www/php-fcgi-scripts/${CLIENT}/
chmod +x /var/www/php-fcgi-scripts/${CLIENT}/php-fcgi-starter

# write config file for $client
echo "#!/bin/bash

# ${CLIENT} config file

CLIENT=${CLIENT}
CLIENTSITE=${DOMAIN}
CLIENTNIMDA=${NIMDA}
CLIENTNIMDAURL=${NIMDA}.${DOMAIN}
CLIENTPATH=/home/www/html/${CLIENT}
CLIENTNIMDAPATH=/home/www/html/${CLIENT}/${NIMDA}.${DOMAIN}
CLIENTPASS=${CLIENTPASS}"  > /etc/${SOFTNAME}/clients/${CLIENT}.conf
chmod 600 /etc/${SOFTNAME}/clients/${CLIENT}.conf

source /etc/${SOFTNAME}/clients/${CLIENT}.conf

# create sql user
mysql -uroot -p${ROOTSQL} -e "CREATE USER '${CLIENT}'@'localhost' IDENTIFIED BY '${CLIENTPASS}'; GRANT USAGE ON * . * TO '${CLIENT}'@'localhost' IDENTIFIED BY '${CLIENTPASS}' WITH MAX_QUERIES_PER_HOUR 0 MAX_CONNECTIONS_PER_HOUR 0 MAX_UPDATES_PER_HOUR 0 MAX_USER_CONNECTIONS 0 ; GRANT ALL PRIVILEGES ON \`${CLIENT}\_%\` . * TO '${CLIENT}'@'localhost';"
